# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`awstats`](#awstats): Install and configure awstats

#### Private Classes

* `awstats::plugin::decodeutfkeys`
* `awstats::plugin::geoip`

### Defined types

* [`awstats::conf`](#awstatsconf): manage awstats config file

## Classes

### <a name="awstats"></a>`awstats`

Install and configure awstats

#### Parameters

The following parameters are available in the `awstats` class:

* [`owner`](#owner)
* [`group`](#group)
* [`config_dir_path`](#config_dir_path)
* [`packages`](#packages)
* [`config_dir_purge`](#config_dir_purge)
* [`enable_plugins`](#enable_plugins)

##### <a name="owner"></a>`owner`

Data type: `String`

awstats role user.

##### <a name="group"></a>`group`

Data type: `String`

awstats role group.

##### <a name="config_dir_path"></a>`config_dir_path`

Data type: `Stdlib::Absolutepath`

Path of the awstats configuration directory.

##### <a name="packages"></a>`packages`

Data type: `Optional[Array[String[1]]]`

List of packages to install.

Default value: ``undef``

##### <a name="config_dir_purge"></a>`config_dir_purge`

Data type: `Boolean`

Default to: `false`

If set to `true`, unmanaged files in the configuration directory path,
typically `/etc/awstats/` are purged.

Default value: ``false``

##### <a name="enable_plugins"></a>`enable_plugins`

Data type: `Array[String]`

Defaults to: `[]`

A case insensitive list of awstats plugins to enable "support" for by
installing required dependencies. The supported plugins are:

* decodeutfkeys
* geoip

Default value: `[]`

## Defined types

### <a name="awstatsconf"></a>`awstats::conf`

```puppet
# defaults
awstats::conf { '<title>':
  template        => undef,
  options         => {},
}
```

```puppet
  $default_options = {
    'LogFile'     => '/var/log/httpd/access_log',
    'LogFormat'   => '1',
    'DirData'     => '/var/lib/awstats',
    'SiteDomain'  => $::fqdn,
    'HostAliases' => "localhost 127.0.0.1 ${::hostname}"
  }
```

  If a hash value is an array, multiple configuration file options with the
  same key name will be created. Eg.

```puppet
  options         => {
    'LoadPlugin'  => ['foo', 'bar'],
  }
```

  Would result in the following options in the configuration file.  Note that
  the order is sorted.

```
LoadPlugin="bar"
LoadPlugin="foo"
```

#### Parameters

The following parameters are available in the `awstats::conf` defined type:

* [`template`](#template)
* [`options`](#options)

##### <a name="template"></a>`template`

Data type: `Optional[String]`

Defaults to `undef`

The path to the puppet ERB template to use to generate the configuration
file.

A value of `undef` is equivalent to `${module_name}/awstats.conf.erb`.

Default value: ``undef``

##### <a name="options"></a>`options`

Data type: `Hash`

Defaults to `{}`

A hash of awstats configuration file options.  The case of keys is preserved
and no validation of what is or isn't a valid awstats directive is performed.
The options hash is merged with these default values, which were determined to
be the minimum set of required parameters via trial and error with EPEL6
`awstats-7.0-3.el6.noarch` package.

Default value: `{}`

